==> haskell-microlens-platform-0.4.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-platform
version:              0.4.1
visibility:           public
id:                   microlens-platform-0.4.1-3prLbnhNNudGQK2KXn2XiW
key:                  microlens-platform-0.4.1-3prLbnhNNudGQK2KXn2XiW
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.

    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  3eceb4727f83be894f291b3f0e2e95e5
exposed:              True
exposed-modules:      Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/microlens-platform-0.4.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/microlens-platform-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/microlens-platform-0.4.1
hs-libraries:         HSmicrolens-platform-0.4.1-3prLbnhNNudGQK2KXn2XiW
depends:
    base-4.14.0.0 hashable-1.3.0.0-AB9JnYTvt0wF1yqQjaMyNP
    microlens-0.4.11.2-DI50OTT3llTDsW32epWmE8
    microlens-ghc-0.4.12-HZQZm4720jE9pTHm6MwJvq
    microlens-mtl-0.2.0.1-30gu8BHYazP9sT79KAgW65
    microlens-th-0.4.3.5-9n2o51UXxOZ7SrtcDAHpl9 text-1.2.3.2
    unordered-containers-0.2.11.0-9heg0ZMZ4fiE5I8jXNtXdI
    vector-0.12.1.2-CYdo0xBKGbnK8ZGEF4yFOM

haddock-interfaces:
    /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock

haddock-html:         /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-platform-0.4.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-platform
version:              0.4.1
visibility:           public
id:                   microlens-platform-0.4.1-6JPHs9MZK3bJdG8TlLFj8o
key:                  microlens-platform-0.4.1-6JPHs9MZK3bJdG8TlLFj8o
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.

    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  7f4827638e16ab8608311ea1335eb280
exposed:              True
exposed-modules:      Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/microlens-platform-0.4.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/microlens-platform-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/microlens-platform-0.4.1
hs-libraries:         HSmicrolens-platform-0.4.1-6JPHs9MZK3bJdG8TlLFj8o
depends:
    base-4.14.0.0 hashable-1.3.0.0-9F611IS0xQZAXu85l3N6Qy
    microlens-0.4.11.2-DI50OTT3llTDsW32epWmE8
    microlens-ghc-0.4.12-HZQZm4720jE9pTHm6MwJvq
    microlens-mtl-0.2.0.1-30gu8BHYazP9sT79KAgW65
    microlens-th-0.4.3.5-9n2o51UXxOZ7SrtcDAHpl9 text-1.2.3.2
    unordered-containers-0.2.12.0-8JXKszpgMXuybqLOiZpMH
    vector-0.12.1.2-KotqULZza37AeFlfLxbJau

haddock-interfaces:
    /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock

haddock-html:         /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
